/*
   Copyright (C) 2011 Ove Kaaven

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
*/

#if HAVE_CONFIG_H
#include "config.h"
#endif
#include <libxml/tree.h>

void load_settings(const char *fname);
void unload_settings(void);

xmlNodePtr get_region(const char *number, const char *mcc);
xmlChar *get_region_code(xmlNodePtr region);
xmlChar *get_region_name(xmlNodePtr region);
xmlChar *get_region_prefix(xmlNodePtr region);
const char *skip_prefix(xmlNodePtr region, const char *number);
xmlNodePtr get_region_directory(xmlNodePtr region, const char *number);
FILE *get_region_text(xmlNodePtr region, const char *number);
